# J1850-PWM-Encoding-Library
Arduino library which allow to communicate on J1850-PWM mode.
It works with both wire and radio transmissions.
You just have to choose your bit-rate (lower is better).
It doesn't have either a header nor a parity check. These functions could be implemented at a higher protocol layer.
This library has been tested also with FSK (and OOK) module RTX-MID-868. Datasheet: https://goo.gl/UEv8ii

## Connections between two Arduino via Wire(DEFAULT)
Arduino Uno (TX)  |  Arduino Uno (RX)  |    Notes  
-------------|-------------|------------
13 | 3 | Intelligent signal
GND | GND | Common GND 

## Connections to RTX-MID-868 on Tx (DEFAULT)
Arduino Uno (TX)  |  RTX-MID-868  |    Notes  
-------------|-------------|------------
13 | 4 | Intelligent signal
12 | 5 | Enable TX/RX
11 | 6 | Power Up/Down
+5V | 10 | +2,5V ÷ +6V 
GND | 2, 7 | Common GND 

## Connections to RTX-MID-868 on Rx (DEFAULT)
Arduino Uno (RX)  |  RTX-MID-868  |    Notes  
-------------|-------------|------------
3 | 9 | Intelligent signal
+5V | 10 | +2,5V ÷ +6V 
GND | 2, 7 | Common GND 

## Encoder Functions Explained
Functions  |    Notes  
-------------|-------------
PwmEncoder(uint8_t TX_PIN); | Initialize transmission pin
PwmEncoder(uint8_t TX_PIN, uint8_t MODE_PIN, uint8_t EN_PIN); | Initialize transmission pin, mode pin (tx or rx), enable pin (to power up/down the module)
void setTxPin(uint8_t TX_PIN); | Set transmission pin
void setEnablePin(uint8_t EN_PIN); | Set enable pin (to power up/down the module)
void setTxRxModePin(uint8_t MODE_PIN); | Set mode pin (tx or rx)
uint8_t getTxPin(); | Return the number of transmission pin
void begin(uint32_t BITRATE); | Initialize  bitrate
void powerDown(); | Power down the module using the enable pin
void powerUp(); | Power up the module using the enable pin
void enableTxMode(); | Enable transmission (normal) mode
void enableRxMode(); | Disable transmission mode
void println(String txt); | Send a string with '\n' and '\r'
void print(String txt); | Send a string
void print(char txt[]); | Send an array char
void print(char c); | Send a single char
void print(uint8_t n); | Send a number (unsigned 8 bits)
void send (bool b); | Send a single j1850-pwm binary value (used by "prints" functions)

## Decoder Functions Explained
Functions  |    Notes  
-------------|-------------
PwmDecoder(uint8_t RX_PIN); | Initialize reception pin
void setRxPin(uint8_t RX_PIN); | Set reception pin
uint8_t getRxPin(); | Return the number of reception pin
void begin(uint32_t BITRATE); | Initialize bitrate
static void isrPwmDecoder(); | Interrupt service routine (called when a rising front is detected)
void receive(); | Read data by reception pin and memorize it on a buffer (array char)
bool isReceiving(); | Return true if the system has received data in the last 'n' milliseconds.
bool available(); | Return true if the buffer (array char) is loaded.
String readString(); | Return the entire buffer
